@@ -17,11 +17,13 @@
 #' df <- list_sites()
 #' }
 
-list_sites <- function(out_dir = tempdir(),
-                       internal = TRUE){
+list_sites <- memoise::memoise(
+  function(
+    out_dir = tempdir(),
+    internal = TRUE){
   
   # download json data using httr
-  error = try(httr::content(httr::GET(url = "https://phenocam.sr.unh.edu/webcam/network/siteinfo/",
+  error = try(httr::content(httr::GET(url = server_lists(),
                                       httr::timeout(30)),
                             "text",
                             encoding = "UTF-8"))
@@ -44,4 +46,4 @@ list_sites <- function(out_dir = tempdir(),
                        row.names = FALSE,
                        quote = FALSE) 
   }
-}
\ No newline at end of file
+})
\ No newline at end of file
