@@ -13,7 +13,16 @@
 #' }
 
 phenocam_explorer = function(){
-  appDir = sprintf("%s/shiny/phenocam_explorer",path.package("phenocamr"))
+  if(!requireNamespace(c("DT",
+                         "plotly",
+                         "shinydashboard",
+                         "leaflet"), quietly = TRUE)){
+    stop("Packages \"DT, plotly, shinydashboard and leaflet\" are needed 
+         for this function to work. Please install it.",
+         call. = FALSE)
+  }
+  
+  appDir = sprintf("%s/shiny/phenocam_explorer", path.package("phenocamr"))
   suppressWarnings(shiny::runApp(appDir,
                 display.mode = "normal",
                 launch.browser = TRUE))
